<?php

namespace Axepta\Payment;

/**
 * Class Util
 *
 * @package Axepta\Payment
 */
class Util
{

	/**
	 * @var string
	 */
	const METHOD_REQUEST_GET = 'GET';

	/**
	 * @var string
	 */
	const METHOD_REQUEST_POST = 'POST';

	/**
	 * @var string
	 */
	const ENVIRONMENT_PRODUCTION = 'production';

	/**
	 * @var string
	 */
	const ENVIRONMENT_SANDBOX = 'sandbox';

	/**
	 * @var array
	 */
	private static $supportedCurrencies = [
		'pln' => 'PLN',
	];

	/**
	 * @var array
	 */
	private static $paymentMethods = [];

	/**
	 * @var array
	 */
	private static $paymentMethodCodes = [];

	/**
	 * @var array
	 */
	private static $hashMethods = [
		'sha224' => 'sha224',
		'sha256' => 'sha256',
		'sha384' => 'sha384',
		'sha512' => 'sha512',
	];

	/**
	 * @var array
	 */
	private static $transactionStatuses = [
		'new'        => 'new',
		'authorized' => 'authorized',
		'pending'    => 'pending',
		'submitted_for_settlement'
		             => 'submitted_for_settlement',
		'rejected'   => 'rejected',
		'settled'    => 'settled',
		'error'      => 'error',
		'cancelled'  => 'cancelled',
	];

	/**
	 * @param string $paymentMethod
	 *
	 * @return string
	 */
	public static function getPaymentMethod($paymentMethod)
	{

		if(isset(self::$paymentMethods[$paymentMethod])) {
			return self::$paymentMethods[$paymentMethod];
		}

		return '';
	}

	/**
	 * @param string $hashMethod
	 *
	 * @return string
	 */
	public static function getHashMethod($hashMethod)
	{

		if(isset(self::$hashMethods[$hashMethod])) {
			return self::$hashMethods[$hashMethod];
		}

		return '';
	}

	/**
	 * Functions that return true when passed currency is on supported currencies list.
	 *
	 * @param string $currencyCode ISO4217
	 * @param array  $currencyList
	 *
	 * @return bool
	 */
	public static function canUseForCurrency($currencyCode, $currencyList)
	{
		return in_array($currencyCode, $currencyList);
	}

	/**
	 * @return array
	 */
	public static function getSupportedCurrencies()
	{
		return self::$supportedCurrencies;
	}

	/**
	 * @return array
	 */
	public static function getTransactionStatuses()
	{
		return self::$transactionStatuses;
	}

	/**
	 * @param string $paymentMethodCode
	 *
	 * @return string
	 */
	public static function getPaymentMethodCode($paymentMethodCode)
	{
		if(isset(self::$paymentMethodCodes[$paymentMethodCode])) {
			return self::$paymentMethodCodes[$paymentMethodCode];
		}

		return '';
	}

	/**
	 * @param string $string
	 *
	 * @return array
	 */
	public static function parseStringToArray($string)
	{

		$array = [];

		parse_str($string, $array);

		return $array;
	}

	/**
	 * @param string $variable
	 *
	 * @return bool
	 */
	public static function isJson($variable)
	{
		json_decode($variable);

		return (json_last_error() === JSON_ERROR_NONE);
	}

	/**
	 * @param string $hashMethod
	 * @param string $data
	 * @param string $serviceKey
	 *
	 * @return string
	 */
	public static function hashSignature($hashMethod, $data, $serviceKey)
	{
		return hash($hashMethod, $data . $serviceKey);
	}

	/**
	 * @param float $amount
	 *
	 * @return int
	 */
	public static function convertAmountToFractional($amount)
	{
		return (int) self::multiplyValues(round($amount, 2), 100, 0);
	}

	/**
	 * @param number $firstValue
	 * @param number $secondValue
	 * @param number $precision
	 *
	 * @return float
	 */
	public static function multiplyValues($firstValue, $secondValue, $precision)
	{
		return round($firstValue * $secondValue, $precision);
	}

	/**
	 * @param int $amount
	 *
	 * @return float
	 */
	public static function convertAmountToMain($amount)
	{

		return round($amount / 100, 2);
	}

	/**
	 * @param array  $order
	 * @param string $url
	 * @param string $methodRequest
	 * @param string $submitValue
	 * @param string $submitClass
	 * @param string $submitStyle
	 *
	 * @return string
	 */
	public static function createOrderForm($order, $url = '', $methodRequest = 'POST', $submitValue = '', $submitClass = '', $submitStyle = '')
	{

		if(!$submitValue) {
			$submitValue = 'Continue';
		}

		if(!$url) {
			return '';
		}

		$form = '<form method="' . $methodRequest . '" action="' . $url . '">';
		foreach($order as $key => $value) {
			$form .= '<input type="hidden" value="' . htmlentities($value) . '" name="' . $key . '" id="axepta_' . $key . '">';
		}
		$form .= '<button type="submit" id="submit-payment-form" style="' . $submitStyle . '" class="' . $submitClass . '">' . $submitValue . '</button>';
		$form .= '</form>';

		return $form;
	}
}
